@@ -1,8 +1,8 @@
 use glib::{subclass::prelude::*, Object};
 
-use crate::PortChannel;
+use crate::{subclass::channel::ChannelImpl, PortChannel};
 
-pub trait PortChannelImpl: ObjectImpl {}
+pub trait PortChannelImpl: ObjectImpl + ChannelImpl {}
 
 unsafe impl<T: PortChannelImpl> IsSubclassable<T> for PortChannel {
     fn class_init(class: &mut glib::Class<Self>) {
